@@ -48,6 +48,14 @@ general_ag.add_argument(
     '--version',
     action='count',
     help='Print the Automated EBS Snapshots version and exit')
+general_ag.add_argument(
+    '--log-file',
+    help='Path to file to send logs to')
+general_ag.add_argument(
+    '--daemon',
+    help=(
+        'Run Automatic EBS Snapshots in daemon mode. Valid modes are '
+        '[start|stop|restart|foreground]'))
 admin_actions_ag = parser.add_argument_group(
     title='Administrative actions')
 admin_actions_ag.add_argument(
